"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.xmlToString = exports.xmlToStringHelper = exports.node = exports.text = void 0;
const text = (value) => ({ type: "text", value });
exports.text = text;
const node = (tag, attrs, children = []) => ({
    type: "node",
    tag,
    attrs,
    children,
});
exports.node = node;
const INDENT_STR = "  ";
const attrsToString = (attrs) => Object.entries(attrs)
    .map(([k, v]) => `${k}="${v}"`)
    .join("");
const indent = (level) => Array.from({ length: level }).fill(INDENT_STR).join("");
const xmlToStringHelper = (level, xml) => {
    const indentationTag = indent(level);
    switch (xml.type) {
        /* istanbul ignore next */
        case "text":
            return indentationTag + xml.value;
        case "node":
            const { tag, children, attrs } = xml;
            const strAttrs = attrsToString(attrs);
            const attrsSpace = strAttrs === "" ? "" : " ";
            if (children.length === 0) {
                return indentationTag + `<${tag}${attrsSpace}${strAttrs} />`;
            }
            else if (children.length === 1 && children[0].type === "text") {
                const child = children[0].value;
                return `${indentationTag}<${tag}${attrsSpace}${strAttrs}> ${child} </${tag}>`;
            }
            else {
                // Uppper
                const openingTag = indentationTag + `<${tag}${attrsSpace}${strAttrs}>`;
                // Body
                const body = children
                    .map(exports.xmlToStringHelper.bind(null, level + 1))
                    .join("\n");
                // Closing
                const closingTag = indentationTag + `</${tag}>`;
                return `${openingTag}\n${body}\n${closingTag}`;
            }
    }
};
exports.xmlToStringHelper = xmlToStringHelper;
const xmlToString = (xml) => (0, exports.xmlToStringHelper)(0, xml);
exports.xmlToString = xmlToString;
