"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reasonToJsonString = exports.reasonToXmlString = void 0;
const xml_1 = require("./internals/xml");
function reasonToXml(reason) {
    switch (reason.type) {
        case "FAIL":
            return (0, xml_1.node)("fail", {}, [(0, xml_1.text)(reason.reason)]);
        case "FIELD_TYPE":
            return (0, xml_1.node)("field-type", { name: reason.field }, [
                reasonToXml(reason.reason),
            ]);
        case "ARRAY":
            return (0, xml_1.node)("array", { index: reason.index }, [
                reasonToXml(reason.reason),
            ]);
        case "ONE_OF":
            return (0, xml_1.node)("one-of", {}, reason.reasons.map(reasonToXml));
        case "MISSING_FIELD":
            return (0, xml_1.node)("missing-field", { name: reason.field });
    }
}
/**
 * Convert to a xml-like string
 *
 * @category Handle failure
 */
function reasonToXmlString(reason) {
    const xml = reasonToXml(reason);
    return (0, xml_1.xmlToString)(xml);
}
exports.reasonToXmlString = reasonToXmlString;
/**
 * Convert to a json-like string
 *
 * @category Handle failure
 */
function reasonToJsonString(reason) {
    return JSON.stringify(reason, null, 2);
}
exports.reasonToJsonString = reasonToJsonString;
