/**
 * A type representing the result of a decoding process
 *
 * @category Decode
 */
export type Result<T> = {
    error: false;
    value: T;
} | {
    error: true;
    reason: Reason;
};
/**
 * A type representing the reason of a decoding failure
 *
 * @category Handle failure
 */
export type Reason = {
    type: "FAIL";
    reason: string;
} | {
    type: "ONE_OF";
    reasons: Reason[];
} | {
    type: "ARRAY";
    index: number;
    reason: Reason;
} | {
    type: "MISSING_FIELD";
    field: string;
} | {
    type: "FIELD_TYPE";
    field: string;
    reason: Reason;
};
/**
 * Convert to a xml-like string
 *
 * @category Handle failure
 */
export declare function reasonToXmlString(reason: Reason): string;
/**
 * Convert to a json-like string
 *
 * @category Handle failure
 */
export declare function reasonToJsonString(reason: Reason): string;
//# sourceMappingURL=result.d.ts.map