import { xmlToString, text, node } from "./internals/xml";
function reasonToXml(reason) {
    switch (reason.type) {
        case "FAIL":
            return node("fail", {}, [text(reason.reason)]);
        case "FIELD_TYPE":
            return node("field-type", { name: reason.field }, [
                reasonToXml(reason.reason),
            ]);
        case "ARRAY":
            return node("array", { index: reason.index }, [
                reasonToXml(reason.reason),
            ]);
        case "ONE_OF":
            return node("one-of", {}, reason.reasons.map(reasonToXml));
        case "MISSING_FIELD":
            return node("missing-field", { name: reason.field });
    }
}
/**
 * Convert to a xml-like string
 *
 * @category Handle failure
 */
export function reasonToXmlString(reason) {
    const xml = reasonToXml(reason);
    return xmlToString(xml);
}
/**
 * Convert to a json-like string
 *
 * @category Handle failure
 */
export function reasonToJsonString(reason) {
    return JSON.stringify(reason, null, 2);
}
